@@ -10,6 +10,9 @@ from transformers import (
     CamembertTokenizer,
     CamembertTokenizerFast,
     DebertaTokenizer,
+    DebertaTokenizerFast,
+    DebertaV2Tokenizer,
+    DebertaV2TokenizerFast,
     DistilBertTokenizer,
     DistilBertTokenizerFast,
     MobileBertTokenizer,
@@ -33,6 +36,9 @@ MODELS_WITH_STARTING_TOKEN = (
     CamembertTokenizer,
     CamembertTokenizerFast,
     DebertaTokenizer,
+    DebertaTokenizerFast,
+    DebertaV2Tokenizer,
+    DebertaV2TokenizerFast,
     RobertaTokenizer,
     RobertaTokenizerFast,
     XLMRobertaTokenizer,
